#!/usr/bin/env python3

import os
import unittest
import yaml
import amulet
import sys
import time


# Lots of prereqs on this charm (eg: java), so give it a large timeout
seconds_to_wait = 20000


class BundleTest(unittest.TestCase):
    """ Create a class for testing the charm in the unit test framework. """
    @classmethod
    def setUpClass(cls):
        """
        Trivial deployment test for IBM Platform Symphony Storage.

        This charm cannot do anything useful by itself, it will deploy Platform Symphony Storage
        and allow the /opt/ibm/platformsymphony files to be shared.
        So integration testing is done in the bundle.
        """

        d = amulet.Deployment(series='trusty')
        config = {}
        local_path = os.path.join(os.path.dirname(__file__), 'local.yaml')
        with open(local_path, "r") as fd:
           config = yaml.safe_load(fd)

        curl_url = config.get('ibm-repo').get('symphony_curl_url')
        if not curl_url:
             message = 'Please provide the curl url from where the package can be downloaded.'
             amulet.raise_status(amulet.FAIL, msg=message)
             sys.exit(1)
        curl_opts =  config.get('ibm-repo').get('symphony_curl_opts')
        if not curl_opts:
             message = 'Please provide the curl_opts to specify the credentials to download the packages.'
             amulet.raise_status(amulet.FAIL, msg=message)
             sys.exit(1)
        d.add('ibm-platform-symphony-master')
        d.add('ibm-platform-symphony-storage')
        d.configure('ibm-platform-symphony-storage', { 'license_accepted': True, 
                                 'curl_url': curl_url, 
                                 'curl_opts': curl_opts })
        #time.sleep(150)
        d.relate('ibm-platform-symphony-storage:storage', 'ibm-platform-symphony-master:storage')
        d.setup(seconds_to_wait)
        d.sentry.wait(seconds_to_wait)
        cls.d = d
               

    def test_unit_deployed(self):
        # verify unit
        self.assertTrue(self.d.deployed)
        unit_master_0 = self.d.sentry['ibm-platform-symphony-master'][0]
        state_master = unit_master_0.info['agent-state']
        print('Master Server is %s' % state_master)
        master_ip = unit_master_0.info['public-address']
        print('Master Server IP is %s' % master_ip)
        cmd1, code = unit_master_0.run(". /opt/ibm/symphony/profile.symphony;egosh ego start;egosh user logon -u Admin -x Admin;egosh resource list -l")
        if code != 0:
         message = 'lsid command failed to run , may be Symphony is down.'
         amulet.raise_status(amulet.FAIL, msg=message)
        print('The output of command on master host is \n')
        print(str(cmd1))
        

if __name__ == '__main__':
    unittest.main()
